Struct sc_transaction_pool::Pool [−][src]
pub struct Pool<B: ChainApi> { /* fields omitted */ }Expand description
Extrinsics pool that performs validation.
Implementations
Create a new transaction pool.
Imports a bunch of unverified extrinsics to the pool
Resubmit the given extrinsics to the pool.
This does not check if a transaction is banned, before we verify it again.
Imports one unverified extrinsic to the pool
Import a single extrinsic and starts to watch its progress in the pool.
Resubmit some transaction that were validated elsewhere.
Prunes known ready transactions.
Used to clear the pool from transactions that were part of recently imported block.
The main difference from the prune is that we do not revalidate any transactions
and ignore unknown passed hashes.
Prunes ready transactions.
Used to clear the pool from transactions that were part of recently imported block.
To perform pruning we need the tags that each extrinsic provides and to avoid calling
into runtime too often we first lookup all extrinsics that are in the pool and get
their provided tags from there. Otherwise we query the runtime at the parent block.
Prunes ready transactions that provide given list of tags.
Given tags are assumed to be always provided now, so all transactions in the Future Queue that require that particular tag (and have other requirements satisfied) are promoted to Ready Queue.
Moreover for each provided tag we remove transactions in the pool that:
- Provide that tag directly
- Are a dependency of pruned transaction.
Returns transactions that have been removed from the pool and must be reverified before reinserting to the pool.
By removing predecessor transactions as well we might actually end up
pruning too much, so all removed transactions are reverified against
the runtime (validate_transaction) to make sure they are invalid.
However we avoid revalidating transactions that are contained within
the second parameter of known_imported_hashes. These transactions
(if pruned) are not revalidated and become temporarily banned to
prevent importing them in the (near) future.
Returns transaction hash
get a reference to the underlying validated pool.